@@ -2,19 +2,19 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2012 Andrew Ziem
+## Copyright (C) 2013 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation, either version 3 of the License, or
 ## (at your option) any later version.
-## 
+##
 ## This program is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
-## 
+##
 ## You should have received a copy of the GNU General Public License
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -39,6 +39,11 @@ if 'posix' == os.name and os.path.isdir('/usr/share/bleachbit'):
 
 if 1 == len(sys.argv):
     import gtk
+    try:
+        gtk.gdk.Screen().get_display()
+    except RuntimeError:
+        print "Could not open X display"
+        sys.exit(1)
     import bleachbit.GUI
     gui = bleachbit.GUI.GUI()
     gtk.main()
