@@ -30,7 +30,7 @@ import optparse
 import os
 import sys
 
-from Cleaner import backends
+from Cleaner import backends, create_simple_cleaner, register_cleaners
 from Common import _, APP_VERSION
 import Options
 import Worker
@@ -75,18 +75,9 @@ class CliCallback:
         pass
 
 
-def init_cleaners():
-    """Prepare the cleaners for use"""
-    import CleanerML
-    CleanerML.load_cleaners()
-    if 'nt' == os.name:
-        import Winapp
-        Winapp.load_cleaners()
-
-
 def cleaners_list():
     """Yield each cleaner-option pair"""
-    init_cleaners()
+    register_cleaners()
     for key in sorted(backends):
         c_id = backends[key].get_id()
         for (o_id, o_name) in backends[key].get_options():
@@ -109,7 +100,7 @@ def preview_or_clean(operations, really_clean):
 
 def args_to_operations(args, preset):
     """Read arguments and return list of operations"""
-    init_cleaners()
+    register_cleaners()
     operations = {}
     if preset:
         # restore presets from the GUI
@@ -152,10 +143,11 @@ def process_cmd_line():
     parser.add_option("-l", "--list-cleaners", action = "store_true",
         help = _("list cleaners"))
     parser.add_option("-c", "--clean", action = "store_true",
-        help = _("delete files and make other permanent changes"))
-    parser.add_option("-d", "--delete", action = "store_true",
-        # TRANSLATORS: this is a warning for using --delete which will go away one day
-        help = _("depreciated alias for --clean"))
+        # TRANSLATORS: predefined cleaners are for applications, such as Firefox and Flash.
+        # This is different than cleaning an arbitrary file, such as a spreadsheet on the desktop.
+        help = _("run cleaners to delete files and make other permanent changes"))
+    parser.add_option("-s", "--shred", action = "store_true",
+        help = _("shred specific files or folders"))
     parser.add_option("--sysinfo", action = "store_true",
         help = _("show system information"))
     parser.add_option("--gui", action = "store_true", help=_("launch the graphical interface"))
@@ -188,30 +180,43 @@ There is NO WARRANTY, to the extent permitted by law.""" % APP_VERSION
     if 'nt' == os.name and options.update_winapp2:
         import Update
         print "Checking online for updates to winapp2.ini"
-        Update.check_updates(False, True, lambda x: sys.stdout.write("%s\n" % x))
+        Update.check_updates(False, True,
+            lambda x: sys.stdout.write("%s\n" % x),
+            lambda: None)
         # updates can be combined with --list, --preview, --clean
         did_something = True
     if options.list_cleaners:
         list_cleaners()
         sys.exit(0)
-    if options.preview:
+    if options.preview or options.clean:
         operations = args_to_operations(args, options.preset)
+        if not operations:
+            print 'ERROR: No work to do.  Specify options.'
+            sys.exit(1)
+    if options.preview:
         preview_or_clean(operations, False)
         sys.exit(0)
     if options.overwrite:
+        if not options.clean or options.shred:
+            print 'NOTE: --overwrite is intended only for use with --clean'
         Options.options.set('shred', True, commit = False)
-    if options.delete:
-        print 'Depreciation warning: use --clean instead of --delete'
-    if options.delete or options.clean:
-        operations = args_to_operations(args, options.preset)
+    if options.clean:
         preview_or_clean(operations, True)
         sys.exit(0)
     if options.gui:
         import gtk
         import GUI
-        GUI.GUI(uac=not options.no_uac)
+        shred_paths = args if options.shred else None
+        GUI.GUI(uac = not options.no_uac, shred_paths = shred_paths)
         gtk.main()
         sys.exit(0)
+    if options.shred:
+        # delete arbitrary files without GUI
+        # create a temporary cleaner object
+        backends['_gui'] = create_simple_cleaner(args)
+        operations = { '_gui' : [ 'files' ] }
+        preview_or_clean(operations, True)
+        sys.exit(0)
     if options.sysinfo:
         import Diagnostic
         print Diagnostic.diagnostic_info()
