@@ -31,7 +31,7 @@ import sys
 if 'nt' == os.name:
     from win32com.shell import shell, shellcon
 
-APP_VERSION = "0.9.6"
+APP_VERSION = "1.0"
 APP_NAME = "BleachBit"
 APP_URL = "http://bleachbit.sourceforge.net"
 
@@ -115,7 +115,6 @@ for __icon in __icons:
 if os.path.exists("./locale/"):
     # local locale (personal)
     locale_dir = os.path.abspath("./locale/")
-    print "debug: locale_dir = '%s'" % (locale_dir, )
 else:
     # system-wide installed locale
     if sys.platform.startswith('linux'):
