@@ -37,7 +37,7 @@ warnings.simplefilter('default')
 from Common import _, _p, APP_NAME, APP_VERSION, APP_URL, appicon_path, \
     help_contents_url, license_filename, options_file, options_dir, \
     online_update_notification_enabled, release_notes_url, portable_mode
-from Cleaner import backends
+from Cleaner import backends, register_cleaners
 from GuiPreferences import PreferencesDialog
 from Options import options
 import Cleaner
@@ -96,9 +96,8 @@ class TreeInfoModel:
             c_name = backends[key].get_name()
             c_id = backends[key].get_id()
             c_value = options.get_tree(c_id, None)
-            if not c_value and options.get('auto_hide') \
-                and backends[key].auto_hide():
-                #print "info: automatically hiding cleaner '%s'" % (c_id)
+            if not c_value and backends[key].auto_hide():
+                # hide irrelevant cleaner (e.g., the application is not detected)
                 continue
             parent = self.tree_store.append(None, (c_name, c_value, c_id))
             for (o_id, o_name) in backends[key].get_options():
@@ -458,14 +457,20 @@ class GUI:
 
     def cb_preferences_dialog(self, action):
         """Callback for preferences dialog"""
-        pref = PreferencesDialog(self.window, self.cb_refresh_operations)
+        pref = PreferencesDialog(self.window)
         pref.run()
 
 
     def cb_refresh_operations(self):
         """Callback to refresh the list of cleaners"""
+        # reload cleaners from disk
+        register_cleaners()
+        # update tree view
         self.tree_store.refresh_rows()
+        # expand tree view
         self.view.expand_all()
+        # remove from idle loop (see gobject.idle_add)
+        return False
 
 
     def cb_run_option(self, widget, really_delete, cleaner_id, option_id):
@@ -760,7 +765,10 @@ class GUI:
         """Check for software updates in background"""
         import Update
         try:
-            updates = Update.check_updates(options.get('check_beta'), options.get('update_winapp2'), self.append_text)
+            updates = Update.check_updates(options.get('check_beta'),
+                options.get('update_winapp2'),
+                self.append_text,
+                lambda: gobject.idle_add(self.cb_refresh_operations))
             if updates:
                 gobject.idle_add(lambda: Update.update_dialog(self.window, updates))
         except:
@@ -768,21 +776,20 @@ class GUI:
             self.append_text(_("Error when checking for updates: ") + str(sys.exc_info()[1]), 'error')
 
 
-    def __init__(self, uac=True):
+    def __init__(self, uac = True, shred_paths = None):
         if uac and 'nt' == os.name and Windows.elevate_privileges():
             # privileges escalated in other process
             sys.exit(0)
         import RecognizeCleanerML
         RecognizeCleanerML.RecognizeCleanerML()
-        import CleanerML
-        CleanerML.load_cleaners()
-        if 'nt' == os.name:
-            import Winapp
-            Winapp.load_cleaners()
+        register_cleaners()
         self.create_window()
         gobject.threads_init()
+        if shred_paths:
+            self.shred_paths(shred_paths)
+            return
         if options.get("first_start") and 'posix' == os.name:
-            pref = PreferencesDialog(self.window, self.cb_refresh_operations)
+            pref = PreferencesDialog(self.window)
             pref.run()
             options.set('first_start', False)
         if online_update_notification_enabled and options.get("check_online_updates"):
