@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2012 Andrew Ziem
+## Copyright (C) 2013 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -36,7 +36,6 @@ import hashlib
 from Common import _, _p
 from CleanerML import list_cleanerml_files
 from Options import options
-import GuiBasic
 
 
 
@@ -116,6 +115,7 @@ def cleaner_change_dialog(changes, parent):
         if 0 == len(delete):
             # no files selected to delete
             break
+        import GuiBasic
         if not GuiBasic.delete_confirmation_dialog(parent, mention_preview = False):
             # confirmation not accepted, so do not delete files
             continue
@@ -151,7 +151,7 @@ class RecognizeCleanerML:
         body = file(pathname).read()
         new_hash = hashdigest(self.salt + body)
         try:
-            known_hash = options.get(pathname, 'hashpath')
+            known_hash = options.get_hashpath(pathname)
         except ConfigParser.NoOptionError:
             return (NEW, new_hash)
         if new_hash == known_hash:
@@ -174,7 +174,7 @@ class RecognizeCleanerML:
                 myhash = change[2]
                 print "info: remembering CleanerML file '%s'" % pathname
                 if os.path.exists(pathname):
-                    options.set(pathname, myhash, 'hashpath')
+                    options.set_hashpath(pathname, myhash)
 
 
 
