@@ -88,11 +88,13 @@ def delete_chrome_favicons(path):
     ver = __get_chrome_history(path)
     cmds = ""
 
-    if ver in [4, 20, 22, 23, 25]:
+    if ver in [4, 20, 22, 23, 25, 26, 28]:
         # Version 4 includes Chromium 12
         # Version 20 includes Chromium 14, Google Chrome 15, Google Chrome 19
         # Version 22 includes Google Chrome 20
         # Version 25 is Google Chrome 26
+        # Version 26 is Google Chrome 29
+        # Version 28 is Google Chrome 30
 
         # icon_mapping
         cols = ('page_url',)
@@ -102,8 +104,17 @@ def delete_chrome_favicons(path):
             where = "where page_url not in (select distinct url from History.urls)"
         cmds += __shred_sqlite_char_columns('icon_mapping', cols, where)
 
+        # favicon images
+        cols = ('image_data', )
+        where = "where id not in (select distinct id from icon_mapping)"
+        cmds += __shred_sqlite_char_columns('favicon_bitmaps', cols, where)
+
         # favicons
-        cols = ('url', 'image_data')
+        # Google Chrome 30 (database version 28): image_data moved to table favicon_bitmaps
+        if ver < 28:
+            cols = ('url', 'image_data')
+        else:
+            cols = ('url', )
         where = "where id not in (select distinct icon_id from icon_mapping)"
         cmds += __shred_sqlite_char_columns('favicons', cols, where)
     elif 3 == ver:
@@ -132,11 +143,16 @@ def delete_chrome_history(path):
     cmds = __shred_sqlite_char_columns('urls', cols, where)
     cmds += __shred_sqlite_char_columns('visits')
     cols = ('lower_term', 'term')
-    cmds += __shred_sqlite_char_columns('keyword_search_terms')
+    cmds += __shred_sqlite_char_columns('keyword_search_terms', cols)
     ver = __get_chrome_history(path)
     if ver >= 20:
         # downloads, segments, segment_usage first seen in Chrome 14, Google Chrome 15 (database version = 20)
-        cmds += __shred_sqlite_char_columns('downloads', ('full_path', 'url'))
+        # Google Chrome 30 (database version 28) doesn't have full_path, but it does have current_path and target_path
+        if ver >= 28:
+            cmds += __shred_sqlite_char_columns('downloads', ('current_path', 'target_path'))
+            cmds += __shred_sqlite_char_columns('downloads_url_chains', ('url', ))
+        else:
+            cmds += __shred_sqlite_char_columns('downloads', ('full_path', 'url'))
         cmds += __shred_sqlite_char_columns('segments', ('name',))
         cmds += __shred_sqlite_char_columns('segment_usage')
     FileUtilities.execute_sqlite3(path, cmds)
