@@ -38,7 +38,7 @@ import Common
 from Common import _
 
 
-def update_winapp2(url, hash_expected, append_text):
+def update_winapp2(url, hash_expected, append_text, cb_success):
     """Download latest winapp2.ini file.  Hash is sha512 or None to disable checks"""
     # first, determine whether an update is necessary
     from Common import personal_cleaners_dir
@@ -71,6 +71,7 @@ def update_winapp2(url, hash_expected, append_text):
     f = open(fn, 'w')
     f.write(doc)
     append_text(_('New winapp2.ini was downloaded.'))
+    cb_success()
 
 
 def user_agent():
@@ -137,7 +138,7 @@ def update_dialog(parent, updates):
 
 
 
-def check_updates(check_beta, check_winapp2, append_text):
+def check_updates(check_beta, check_winapp2, append_text, cb_success):
     """Check for updates via the Internet"""
     opener = urllib2.build_opener()
     socket.setdefaulttimeout(Common.socket_timeout)
@@ -163,8 +164,7 @@ def check_updates(check_beta, check_winapp2, append_text):
     if check_winapp2 and wa_element:
         wa_sha512 = wa_element[0].getAttribute('sha512')
         wa_url = wa_element[0].getAttribute('url')
-        update_winapp2(wa_url, wa_sha512, append_text)
-
+        update_winapp2(wa_url, wa_sha512, append_text, cb_success)
 
     dom.unlink()
 
