@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2012 Andrew Ziem
+## Copyright (C) 2013 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -28,32 +28,41 @@ Import Winapp2.ini files
 import Cleaner
 import Common
 import ConfigParser
+import Windows
 import os
 import re
-import sys
 import traceback
 
-from Action import ActionProvider, Delete, Winreg
+from Action import Delete, Winreg
 from Common import _
-from FileUtilities import listdir
-from General import boolstr_to_bool, getText
-from Windows import detect_registry_key
 from platform import uname
 from xml.dom.minidom import parseString
 
+
+MAX_DETECT = 50
+
 # TRANSLATORS: This is cleaner name for cleaners imported from winapp2.ini
-langsecref_map = { '3021' : _('Applications'), \
+langsecref_map = { '3021' : ('winapp2_applications', _('Applications')), \
 # TRANSLATORS: This is cleaner name for cleaners imported from winapp2.ini
-    '3022' : _('Internet'), \
+    '3022': ('winapp2_internet', _('Internet')), \
 # TRANSLATORS: This is cleaner name for cleaners imported from winapp2.ini
-    '3023' : _('Multimedia'), \
+    '3023': ('winapp2_multimedia',_('Multimedia')), \
 # TRANSLATORS: This is cleaner name for cleaners imported from winapp2.ini
-    '3024': _('Utilities'), \
+    '3024': ('winapp2_utilities', _('Utilities')), \
 # TRANSLATORS: This is cleaner name for cleaners imported from winapp2.ini.
-    '3025' : _('Microsoft Windows'), \
-    '3026' : _('Internet'), \
-    '3027' : _('Internet'), \
-    '3028' : _('Internet') }
+    '3025': ('winapp2_windows', 'Microsoft Windows'), \
+# 3026 = Firefox/Mozilla
+    '3026': ('winapp2_mozilla', 'Firefox/Mozilla'), \
+# 3027 = Opera
+    '3027': ('winapp2_opera', 'Opera'), \
+# 3028 = Safari
+    '3028': ('winapp2_safari', 'Safari'), \
+# 3029 = Google Chrome
+    '3029': ('winapp2_google_chrome', 'Google Chrome'), \
+# 3030 = Thunderbird
+    '3030': ('winapp2_thunderbird', 'thunderbird'),
+# Section=Games (technically not langsecref)
+    'Games': ('winapp2_games', _('Games')) }
 
 def xml_escape(s):
     """Lightweight way to escape XML entities"""
@@ -72,6 +81,23 @@ def preexpand(s):
     return re.sub(r'%([a-zA-Z]+)%', r'${\1}', s)
 
 
+def detectos(required_ver, mock = False):
+    """Returns boolean whether the detectos is compatible with the
+    current operating system, or the mock version, if given."""
+    current_os = (mock if mock else uname()[3])[0:3]
+    required_ver = required_ver.strip()
+    if required_ver.startswith('|'):
+        # This is the maximum version
+        # For example, |5.1 means Windows XP (5.1) but not Vista (6.0)
+        return current_os <= required_ver[1:]
+    elif required_ver.endswith('|'):
+        # This is the minimum version
+        # For example, 6.1| means Windows 7 or later
+        return current_os >= required_ver[:-1]
+    else:
+        # Exact version
+        return required_ver == current_os
+
 class Winapp:
     """Create cleaners from a Winapp2.ini-style file"""
 
@@ -79,12 +105,9 @@ class Winapp:
         """Create cleaners from a Winapp2.ini-style file"""
 
         self.cleaners = {}
+        self.cleaner_ids = []
         for langsecref in set(langsecref_map.values()):
-            lid = langsecref.lower().replace(' ','_')
-            self.cleaners[lid] = Cleaner.Cleaner()
-            self.cleaners[lid].id = lid
-            self.cleaners[lid].name = langsecref
-            self.cleaners[lid].description = _('Imported from winapp2.ini')
+            self.add_section(langsecref[0], langsecref[1])
         self.errors = 0
         self.parser = ConfigParser.RawConfigParser()
         self.parser.read(pathname)
@@ -97,25 +120,81 @@ class Winapp:
                 traceback.print_exc()
 
 
+    def add_section(self, cleaner_id, name):
+        """Add a section (cleaners)"""
+        self.cleaner_ids.append(cleaner_id)
+        self.cleaners[cleaner_id] = Cleaner.Cleaner()
+        self.cleaners[cleaner_id].id = cleaner_id
+        self.cleaners[cleaner_id].name = name
+        self.cleaners[cleaner_id].description = _('Imported from winapp2.ini')
+
+
+    def section_to_cleanerid(self, langsecref):
+        """Given a langsecref (or section name), find the internal
+        BleachBit cleaner ID."""
+        # pre-defined, such as 3021
+        if langsecref in langsecref_map.keys():
+            return langsecref_map[langsecref][0]
+        # custom, such as games
+        cleanerid = 'winapp2_' + section2option(langsecref)
+        if not cleanerid in self.cleaners:
+            # never seen before
+            self.add_section(cleanerid, langsecref)
+        return cleanerid
+
+
     def handle_section(self, section):
         """Parse a section"""
+        def detect_file(rawpath):
+            pathname = os.path.expandvars(preexpand(rawpath))
+            return os.path.exists(pathname)
+        # if simple detection fails then discard the section
         if self.parser.has_option(section, 'detect'):
             key = self.parser.get(section, 'detect')
-            if not detect_registry_key(key):
+            if not Windows.detect_registry_key(key):
                 return
         if self.parser.has_option(section, 'detectfile'):
-            pathname = os.path.expandvars(preexpand(self.parser.get(section, 'detectfile')))
-            if not os.path.exists(pathname):
+            if not detect_file(self.parser.get(section, 'detectfile')):
                 return
         if self.parser.has_option(section, 'detectos'):
-            min_os = self.parser.get(section, 'detectos')
-            cur_os = uname()[3][0:3]
-            if min_os > cur_os:
+            required_ver = self.parser.get(section, 'detectos')
+            if not detectos(required_ver):
                 return
+        # in case of multiple detection, discard if none match
+        if self.parser.has_option(section, 'detectfile1'):
+            matches = 0
+            for n in range(1, MAX_DETECT):
+                option_id = 'detectfile%d' % n
+                if self.parser.has_option(section, option_id):
+                    if detect_file(self.parser.get(section, option_id)):
+                        matches = matches + 1
+            if 0 == matches:
+                return
+        if self.parser.has_option(section, 'detect1'):
+            matches = 0
+            for n in range(1, MAX_DETECT):
+                option_id = 'detect%d' % n
+                if self.parser.has_option(section, option_id):
+                    if Windows.detect_registry_key(self.parser.get(section, option_id)):
+                        matches = matches + 1
+            if 0 == matches:
+                return
+        # not yet implemented
         if self.parser.has_option(section, 'excludekey'):
             print 'ERROR: ExcludeKey not implemented, section=', section
             return
-        lid = langsecref_map[self.parser.get(section, 'langsecref')].lower().replace(' ','_')
+        # there are two ways to specify sections: langsecref= and section=
+        if self.parser.has_option(section, 'langsecref'):
+            # verify the langsecref number is known
+            # langsecref_num is 3021, games, etc.
+            langsecref_num = self.parser.get(section, 'langsecref')
+        elif self.parser.has_option(section, 'section'):
+            langsecref_num = self.parser.get(section, 'section')
+        else:
+            print 'ERROR: neither option LangSecRef nor Section found in section %s' % (section)
+            return
+        # find the BleachBit internal cleaner ID
+        lid = self.section_to_cleanerid(langsecref_num)
         self.cleaners[lid].add_option(section2option(section), section.replace('*', ''), '')
         for option in self.parser.options(section):
             if option.startswith('filekey'):
@@ -124,10 +203,13 @@ class Winapp:
                 self.handle_regkey(lid, section, option)
             elif option == 'warning':
                 self.cleaners[lid].set_warning(section2option(section), self.parser.get(section, 'warning'))
-            elif option in ('default', 'detectfile', 'detect', 'langsecref'):
+            elif option in ('default', 'detectfile', 'detect', 'langsecref', 'section') \
+                or ['detect%d' % x for x in range(1, MAX_DETECT)] \
+                or ['detectfile%d' % x for x in range(1, MAX_DETECT)]:
                 pass
             else:
-                print 'WARNING: unknown option', option
+                print 'WARNING: unknown option %s in section %s' % (option, section)
+                return
 
 
     def __make_file_provider(self, dirname, filename, recurse, removeself):
@@ -162,27 +244,29 @@ class Winapp:
         Section is [Application Name] and option is the FileKey#"""
         elements = self.parser.get(ini_section, ini_option).strip().split('|')
         dirname = preexpand(elements.pop(0))
-        filename = ""
+        filenames = ""
         if elements:
-            filename = elements.pop(0)
+            filenames = elements.pop(0)
         recurse = False
         removeself = False
         for element in elements:
+            element = element.upper()
             if 'RECURSE' == element:
                 recurse = True
             elif 'REMOVESELF' == element:
                 recurse = True
                 removeself = True
             else:
-                print 'WARNING: unknown file option', element
-        for provider in self.__make_file_provider(dirname, filename, recurse, removeself):
-            self.cleaners[lid].add_action(section2option(ini_section), provider)
+                print 'WARNING: unknown file option %s in section %s' % (element, ini_section)
+        for filename in filenames.split(';'):
+            for provider in self.__make_file_provider(dirname, filename, recurse, removeself):
+                self.cleaners[lid].add_action(section2option(ini_section), provider)
 
 
     def handle_regkey(self, lid, ini_section, ini_option):
         """Parse a RegKey# option"""
         elements = self.parser.get(ini_section, ini_option).strip().split('|')
-        path = elements[0]
+        path = xml_escape(elements[0])
         name = ""
         if 2 == len(elements):
             name = 'name="%s"' % xml_escape(elements[1])
@@ -193,10 +277,9 @@ class Winapp:
 
     def get_cleaners(self):
         """Return the created cleaners"""
-        for langsecref in set(langsecref_map.values()):
-            lid = langsecref.lower().replace(' ','_')
-            if self.cleaners[lid].is_usable():
-                yield self.cleaners[lid]
+        for cleaner_id in self.cleaner_ids:
+            if self.cleaners[cleaner_id].is_usable():
+                yield self.cleaners[cleaner_id]
 
 
 def list_winapp_files():
