@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2011 Andrew Ziem
+## Copyright (C) 2013 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -22,7 +22,7 @@
 """
 Functionality specific to Microsoft Windows
 
-The Windows Registry terminology can be confusing. Take for example 
+The Windows Registry terminology can be confusing. Take for example
 the reference
 * HKCU\\Software\\BleachBit
 * CurrentVersion
@@ -68,7 +68,7 @@ import Common
 import FileUtilities
 import General
 
-def browse_file(hwnd, title):
+def browse_file(_, title):
     """Ask the user to select a single file.  Return full path"""
     try:
         ret = win32gui.GetOpenFileNameW(None, \
@@ -85,7 +85,7 @@ def browse_file(hwnd, title):
     return ret[0]
 
 
-def browse_files(hwnd, title):
+def browse_files(_, title):
     """Ask the user to select files.  Return full paths"""
     try:
         ret = win32gui.GetOpenFileNameW(None, \
@@ -297,6 +297,25 @@ def empty_recycle_bin(drive, really_delete):
     return bytes_used
 
 
+def get_autostart_path():
+    """Return the path of the BleachBit shortcut in the user's startup folder"""
+    try:
+        startupdir = shell.SHGetSpecialFolderPath(None, shellcon.CSIDL_STARTUP)
+    except:
+        # example of failure http://bleachbit.sourceforge.net/forum/error-windows-7-x64-bleachbit-091
+        traceback.print_exc()
+        msg = 'Error finding user startup folder: %s ' % (str(sys.exc_info()[1]))
+        import GuiBasic
+        GuiBasic.message_dialog(None, msg)
+        # as a fallback, guess
+        # Windows XP: C:\Documents and Settings\(username)\Start Menu\Programs\Startup
+        # Windows 7: C:\Users\(username)\AppData\Roaming\Microsoft\Windows\Start Menu\Programs\Startup
+        startupdir = os.path.expandvars('$USERPROFILE\\Start Menu\\Programs\\Startup')
+        if not os.path.exists(startupdir):
+            startupdir = os.path.expandvars('$APPDATA\\Roaming\\Microsoft\\Windows\\Start Menu\\Programs\\Startup')
+    return os.path.join(startupdir, 'bleachbit.lnk')
+
+
 def get_fixed_drives():
     """Yield each fixed drive"""
     for drive in win32api.GetLogicalDriveStrings().split('\x00'):
@@ -307,7 +326,6 @@ def get_fixed_drives():
 def is_process_running(name):
     """Return boolean whether process (like firefox.exe) is running"""
 
-    r = []
     if os.getenv('PROGRAMFILES(X86)'):
         # 64-bit Windows detected
         return is_process_running_wmic(name)
@@ -366,7 +384,7 @@ def is_process_running_wmic(name):
 
     clean_name = re.sub('[^A-Za-z\.]', '_', name).lower()
     args = ['wmic', 'path', 'win32_process', 'where', "caption='%s'" % clean_name, 'get', 'Caption']
-    (rc, stdout, stderr) = General.run_external(args)
+    (_, stdout, _) = General.run_external(args)
     return stdout.lower().find(clean_name) > -1
 
 
@@ -381,36 +399,38 @@ def path_on_network(path):
 def split_registry_key(full_key):
     """Given a key like HKLM\Software split into tuple (hive, key).
     Used internally."""
-    assert ( len (full_key) > 6 )
-    hive_str = full_key[0:4]
-    hive_map = { 
+    assert ( len (full_key) >= 6 )
+    [k1, k2] = full_key.split("\\", 1)
+    hive_map = {
         'HKCR' : _winreg.HKEY_CLASSES_ROOT,
         'HKCU' : _winreg.HKEY_CURRENT_USER,
-        'HKLM' : _winreg.HKEY_LOCAL_MACHINE }
-    if hive_str not in hive_map:
-        raise RuntimeError("Invalid Windows registry hive '%s'" % hive_str)
-    return ( hive_map[hive_str], full_key[5:] )
+        'HKLM' : _winreg.HKEY_LOCAL_MACHINE,
+        'HKU' : _winreg.HKEY_USERS }
+    if k1 not in hive_map:
+        raise RuntimeError("Invalid Windows registry hive '%s'" % k1)
+    return ( hive_map[k1], k2 )
 
 
 def start_with_computer(enabled):
     """If enabled, create shortcut to start application with computer.
     If disabled, then delete the shortcut."""
+    autostart_path = get_autostart_path()
     if not enabled:
-        if os.path.lexists(Common.autostart_path):
-            FileUtilities.delete(Common.autostart_path)
+        if os.path.lexists(autostart_path):
+            FileUtilities.delete(autostart_path)
         return
-    if os.path.lexists(Common.autostart_path):
+    if os.path.lexists(autostart_path):
         return
     import win32com.client
-    shell = win32com.client.Dispatch('WScript.Shell')
-    shortcut = shell.CreateShortCut(Common.autostart_path)
+    wscript_shell = win32com.client.Dispatch('WScript.Shell')
+    shortcut = wscript_shell.CreateShortCut(autostart_path)
     shortcut.TargetPath = os.path.join(Common.bleachbit_exe_path, 'bleachbit.exe')
     shortcut.save()
 
 
 def start_with_computer_check():
     """Return boolean whether BleachBit will start with the computer"""
-    return os.path.lexists(Common.autostart_path)
+    return os.path.lexists(get_autostart_path())
 
 
 
